# IBM GeoFM Python SDK

This package is IBM Geospatial Exploration and Orchestration Studio (GEOStudio) SDK for Python. Through the SDK, developers can write software that uses the GEOStudio API services; [GeoStudio APIs](https://terrastackai.github.io/geospatial-studio).

## Getting Started

To get started with `geostudio`, check out the [Getting Started Guideline](GETTING_STARTED.md) to install and develop your GeoFM applications.

## Documentation

The SDK Documentation can be found [here](https://terrastackai.github.io/geospatial-studio-toolkit).

To Update the documentation:
```sh
# 1. Install Dependencies
poetry install --with docs

# 2. Update Docstrings

# 3. Build the Documentation
poetry run docs-build

# 4. Preview in your browser
poetry run docs-serve

# 5. Deploy to gh-pages
poetry run docs-deploy
```

## Contributing

To contibute to the project, check out our [Contribution Guideline](CONTRIBUTING.md) for information about getting involved.
